/*
Pluck: an open source trivia game for Android

Copyright (C) 2021 Joguitos do luca0N!

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.

This game is a fork of LibreTrivia, and its source code is available at
<https://github.com/tryton-vanmeer/LibreTrivia>.

Contact us at <joguitos+pluck@luca0n.com>.
*/

package com.luca0n.joguitos.pluck.settings;

import android.os.Bundle;
import androidx.preference.PreferenceFragmentCompat;

import androidx.annotation.Nullable;
import androidx.preference.ListPreference;
import androidx.preference.CheckBoxPreference;
import androidx.preference.EditTextPreference;
import androidx.preference.Preference;

import com.luca0n.joguitos.pluck.R;
import com.luca0n.joguitos.pluck.util.UiUtil;

public class SettingsFragment extends PreferenceFragmentCompat {
	@Override
	public void onCreate(@Nullable Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
	}

	@Override
	public void onCreatePreferences(Bundle savedInstanceState, String rootKey){
		addPreferencesFromResource(R.xml.preferences);
		// Listen for theme preference changes
		ListPreference preferenceTheme = (ListPreference) findPreference(getString(R.string.pref_ui_theme));
		CheckBoxPreference preferenceTor = (CheckBoxPreference) findPreference(getString(R.string.pref_network_tor)),
											 preferenceProxy = (CheckBoxPreference) findPreference(getString(R.string.pref_network_proxy));
		EditTextPreference preferenceProxyAddress = (EditTextPreference)
			findPreference(getString(R.string.pref_network_proxy_address));

		// A few preferences override others, so let's go ahead and disable some of them based on the user preferences.
		// For more info, please check the comments on the OnPreferenceChangeListener below.
		if (preferenceTor.isChecked()){
			preferenceProxy.setEnabled(false);
			preferenceProxyAddress.setEnabled(false);
		} else if (preferenceProxy.isChecked()){
			preferenceTor.setEnabled(false);
		}

		Preference.OnPreferenceChangeListener listener = new Preference.OnPreferenceChangeListener(){
			@Override
			public boolean onPreferenceChange(Preference preference, Object newValue){
				// Because we are using this listener on multiple preferences, we need to check which one we are currently
				// dealing with.
				if (preference == preferenceTheme){
					// The user changed the app theme. In order to apply changes to this activity, we need to recreate it.
					// This will cause the screen to go black for a brief moment, but will apply the selected theme.
					getActivity().recreate();
				} else if (preference == preferenceTor){
					// Get the new value as a boolean since this is a CheckBoxPreference.
					boolean newBoolean = (boolean) newValue;
					// The user wants the app to use Tor.
					// This option is not compatible with a custom proxy, so let's go ahead and disable custom proxy preferences.
					preferenceProxy.setEnabled(!newBoolean);
					preferenceProxyAddress.setEnabled(!newBoolean);
					// Also uncheck the proxy preference in case it was previously checked.
					if (newBoolean)
						preferenceProxy.setChecked(false);
				} else if (preference == preferenceProxy){
					// Get the new value as a boolean since this is a CheckBoxPreference.
					boolean newBoolean = (boolean) newValue;
					// The user wants the app to use a custom proxy.
					// This option overrides the Tor preference, so let's go ahead and disable the Tor preference.
					preferenceTor.setEnabled(!newBoolean);
					// Also go ahead and uncheck the Tor preference in case it was previously checked.
					if (newBoolean)
						preferenceTor.setChecked(false);
				}
				return true;
			}
		};

		// Set the same listener for these preferences.
		preferenceTor.setOnPreferenceChangeListener(listener);
		preferenceProxy.setOnPreferenceChangeListener(listener);
		preferenceTheme.setOnPreferenceChangeListener(listener);
	}
}
